/**
 * This file is a part of DesQ Session.
 * DesQSession is the Session Manager for DesQ DE.
 * Copyright 2019-2022 Britanicus <marcusbritanicus@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * at your option, any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 **/

#pragma once

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include <QtCore/qcontainerfwd.h>

namespace DesQ {
    namespace Session {
        class Adaptor;
    }
}

class DesQ::Session::Adaptor : public QDBusAbstractAdaptor {
    Q_OBJECT;

    Q_CLASSINFO( "D-Bus Interface", "org.DesQ.SessionManager" );
    Q_CLASSINFO(
        "D-Bus Introspection",
        "<interface name='org.DesQ.SessionManager'>\n"
        "   <method name='Logout'/>\n"
        "   <method name='Suspend'/>\n"
        "   <method name='Hibernate'/>\n"
        "   <method name='Shutdown'/>\n"
        "   <method name='Reboot'/>\n"
        "   <method name='CanSuspend'>\n"
        "       <arg type=\"b\" direction=\"out\"/>\n"
        "   </method>\n"
        "   <method name='CanHibernate'>\n"
        "       <arg type=\"b\" direction=\"out\"/>\n"
        "   </method>\n"
        "   <method name='CanShutdown'>\n"
        "       <arg type=\"b\" direction=\"out\"/>\n"
        "   </method>\n"
        "   <method name='CanReboot'>\n"
        "       <arg type=\"b\" direction=\"out\"/>\n"
        "   </method>\n"
        "</interface>"
    );

    public:
        Adaptor( QObject *parent );

        Q_SLOT void Logout();

        Q_SLOT void Suspend();
        Q_SLOT void Hibernate();
        Q_SLOT void Shutdown();
        Q_SLOT void Reboot();

        Q_SLOT bool CanSuspend();
        Q_SLOT bool CanHibernate();
        Q_SLOT bool CanShutdown();
        Q_SLOT bool CanReboot();
};
